package main

import (
	"encoding/json"
	"flag"
	"fmt"
	"log"
	"os"
	"strconv"
	"time"

	"scm.dairydemon.net/filifa/mlblive/internal/statsapi"
)

func writeTest(v any, ts string) {
	b, err := json.Marshal(v)
	if err != nil {
		log.Println(err)
	}

	os.WriteFile("examples/data/data_"+ts+".json", b, 0644)
}

func getGamePk() string {
	teamId := flag.String("t", "", "team to get updates for")
	flag.Parse()
	if *teamId == "" {
		log.Fatal("need team ID")
	}

	id, ok := statsapi.TeamIds[*teamId]
	if !ok {
		log.Fatal("invalid team ID")
	}

	sched, err := statsapi.Schedule("1", strconv.Itoa(id))
	if err != nil {
		log.Fatal(err)
	}

	gamePk := sched.Dates[0].Games[0].GamePk.String()
	return gamePk
}

func main() {
	gamePk := getGamePk()

	ws, err := statsapi.NewGamedayWebsocket(gamePk)
	if err != nil {
		log.Fatal(err)
	}
	defer ws.Close()

	ch := make(chan error)
	go ws.KeepAlive(10*time.Second, ch)

	feed, err := statsapi.Feed(gamePk)
	if err != nil {
		log.Fatal(err)
	}

	j, err := json.Marshal(feed)
	if err != nil {
		log.Fatal(err)
	}
	fmt.Println(string(j))

	ts := feed["metaData"].(map[string]any)["timeStamp"].(string)

	var p statsapi.Push
	err = ws.ReadJSON(&p)
	if err != nil {
		log.Fatal(err)
	}

	patches, err := statsapi.DiffPatch(gamePk, ts, p.UpdateId)
	if err != nil {
		log.Fatal(err)
	}

	for _, patch := range patches {
		for _, instr := range patch.Diff {
			feed.Patch(&instr)
		}
	}

	j, err = json.Marshal(feed)
	if err != nil {
		log.Fatal(err)
	}
	fmt.Println(string(j))
}
